unit Status;
(*
 This sample unit is part of Table Scanner V3.00 package
 Copyright 1997-1998 by Demian [demian@bhnet.com.br]
*)

{$X+}

interface

uses
  Classes,SysUtils,Forms,StdCtrls,Buttons,ExtCtrls,Dialogs,Controls,MakeDB;

type
  TFormStatus = class(TForm)
    LabelTitle: TLabel;
    LabelTablesT: TLabel;
    LabelTables: TLabel;
    LabelCurrentT: TLabel;
    LabelCurrent: TLabel;
    LabelOperationT: TLabel;
    LabelOperation: TLabel;
    LabelActionT: TLabel;
    LabelAction: TLabel;
    BitBtnCancel: TBitBtn;
    ImageIcon: TImage;
    BevelMain: TBevel;
    ShapeProgress: TShape;
    procedure BitBtnCancelClick(Sender: TObject);
  end;

function DoOnCheckTable(const Sender: TScanInfo): boolean; export;

implementation

{$R *.DFM}

var
  FormStatus: TFormStatus;

{______________________________________________________________________________}
function DoOnCheckTable(const Sender: TScanInfo): boolean;
(*
 This function is called by TBLSCN.DLL and must return a boolean value:
 True, to continue table checking, or False, to abort table checking.
*)
begin
  with FormStatus,Sender do
  case Action of
    {'saStart' occurs before any tables are checked. Should be used to perform
     any required initialization.}
    saStart : begin
                FormStatus := TFormStatus.Create(nil);
                with FormStatus do begin
                  Caption := Application.Title;
                  ImageIcon.Picture.Graphic := Application.Icon;
                  LabelOperation.Caption := 'Start';
                  ShapeProgress.Width := 0;
                  Show;
                end;
              end;
    {'saFinish' occurs after all tables are checked. Should be used to perform
     any required finalization.
     NOTE: This action occurs even when an exception is raised during checking}
    saFinish: begin
                LabelOperation.Caption := 'Finish';
                result := Tag <> -1;
                if not result then
                   ShowMessage('Operation terminated by user');
                FormStatus.Free;
                Exit;
              end;
  else
    {Following actions occur during table checking}
    LabelTables.Caption := IntToStr(TableIndex)+'/'+IntToStr(TableCount);
    LabelCurrent.Caption := TableName;
    ShapeProgress.Width := (BevelMain.Width-20)*(TableIndex) div TableCount;
    case Action of
      saVerify: LabelOperation.Caption := 'Verify';
      saCreate: LabelOperation.Caption := 'Create';
      saRedo  : LabelOperation.Caption := 'Redo';
      saModify: LabelOperation.Caption := 'Modify';
    end;
    LabelAction.Caption := BDEMessage;
  end;
  {Aborts table checking if user clicks Cancel button}
  result := FormStatus.Tag <> -1;
end;

{______________________________________________________________________________}
procedure TFormStatus.BitBtnCancelClick(Sender: TObject);
begin
  {Set flag indicating that user clicked Cancel button}
  Tag := -1;
end;

end.
